// Solution to problem A. Alternate Routes, from CCSS 2015.
//
// Precompute matrix with all numbers of routes.
//
// Solution by Rudy van Vliet, 27 April 2015

#include <iostream>
using namespace std;

const int maxDim = 1000;
int numberRoutes[maxDim+1][maxDim+1];

//*************************************************************************

int intabs (int x)
{
  if (x>=0)
    return x;
  else
    return -x;
}

//*************************************************************************

// Compute matrix with all the answers.
// As matrix is symmetric, we only compute half of it.
// Pre: 0 <= E <= N <= maxDim
void computeMatrix (int N, int E)
{ int i, j;

  for (i=0;i<=N;i++)
    numberRoutes[i][0] = 1;

  for (i=1;i<=N;i++)
  { if (i<=E)  // we must compute up to i
    { for (j=1;j<i;j++)
        numberRoutes[i][j] = (numberRoutes[i-1][j] + numberRoutes[i][j-1])
                                   % 123456789;

        // For j=i, we cannot use numberRoutes[i-1][j]:
      numberRoutes[i][i] = (2*numberRoutes[i][i-1]) % 123456789;
    }
    else  // i>E, so we must compute up to E
    { for (j=1;j<=E;j++)
        numberRoutes[i][j] = (numberRoutes[i-1][j] + numberRoutes[i][j-1])
                                   % 123456789;
    }
  }  // for

}  // computeMatrix

//*************************************************************************

int main ()
{ int T, Inst;
  int N, E;

    // precompute matrix with all the answers
  computeMatrix (maxDim, maxDim);

  cin >> T;
  for (Inst=1;Inst<=T;Inst++)
  { cin >> N >> E;

    N = intabs (N);
    E = intabs (E);

    if (N>maxDim || E>maxDim)
      cout << "Input is incorrect.\n";
    else  // input correct
    {
      if (N>=E)
        cout << numberRoutes[N][E] << endl;
      else
        cout << numberRoutes[E][N] << endl;
    }
  }

  return 0;
}
