// Solution to problem E. European Energy Union, from CCSS 2015.
//
// Uses union-find to connect components of graph, as soon as a connection
// betwoon two nodes/countries is read from input.
//
// In principle, for the efficiency of union-find, we maintain the heights
// of the trees that we build.
// In union, we make the tree with the lowest value for the height,
// a child of the tree with the highest value.
// In find, we make the node that we find, a direct child of the root of its
// tree. As a result, the tree may become less heigh, and the value for
// its height may no longer be correct. Yet, this value remains a useful
// upper bound.
//
// Solution by Rudy van Vliet, 29 April 2015

#include <iostream>
using namespace std;
const int maxC = 2000;
const int maxP = 1000000;
int parent [maxC+1],  // parent of a node in the tree
    height [maxC+1];  // (upper bound for) the height of the subtree rooted
                      // by a node

//*************************************************************************

// Check if value is in the interval minim--maxim (inclusive).
void checkInterval (int value, int minim, int maxim)
{
  if (value<minim || value>maxim)
    cout << "The value " << value << " is not in the interval "
           << minim << "--" << maxim << ".\n";

}  // checkInterval

//*************************************************************************

// Find root of the tree that node i0 is in, and make i0 a direct child
// of this root (unless it is the root itself).
int find (int i0)
{ int i;

  i = i0;
  while (parent[i]!=0)
    i = parent[i];

  if (i!=i0)
    parent[i0] = i;

  return i;
  
}  // find

//*************************************************************************

// Unify the two trees rooted by i1 and i2, respectively.
// Make the tree with the smallest value for the height, a child of the tree
// with the highest value.
void uunion (int i1, int i2)
{
  if (parent[i1]!=0 || parent[i2]!=0)
    cout << "Arguments of union must be roots of their trees.\n";
  else
  { if (height[i1]<height[i2])
      parent[i1] = i2;  // height of tree rooted by i2 does not change
    else
      if (height[i1]==height[i2])
      { parent[i2] = i1;
        height[i1] ++;
      }
      else // height[i1]>height[i2]
        parent[i2] = i1;  // height of tree rooted by i1 does not change
  }

} // uunion

//*************************************************************************

int main ()
{ int T, Inst;
  int C, P,
      i, j,
      X, Y,
      i1, i2,
      components;

  cin >> T;
  for (Inst=1;Inst<=T;Inst++)
  { cin >> C >> P;
    checkInterval (C, 1, maxC);
    checkInterval (P, 0, maxP);

    for (i=1;i<=C;i++)
    { parent[i] = 0;
      height[i] = 1;
    }

    for (j=1;j<=P;j++)
    { cin >> X >> Y;
      checkInterval (X, 1, C-1);
      checkInterval (Y, X+1, C);
      i1 = find (X);
      i2 = find (Y);
      if (i1!=i2)
        uunion (i1,i2);
    }

    components = 0;

    for (i=1;i<=C;i++)
      if (parent[i]==0)
        components ++;

    cout << components-1 << endl;
  }

  return 0;
}
